@@ -2,13 +2,20 @@
 package Sman::Util;
 use Sman;	# for VERSION
 
-#$Id: Util.pm,v 1.36 2006/05/04 19:26:54 joshr Exp $
+#$Id: Util.pm,v 1.43 2008/06/02 22:26:10 joshr Exp $
 
 use strict;
 use warnings;
 use Config;	# to get perl version string
 use File::Temp;	# used in RunCommand()
-use lib '/usr/local/lib/swish-e/perl';
+
+our $VERSION = '1.03_001';
+our $SMAN_DATA_VERSION = "1.4";     # this is only relevant to Sman
+
+#  TODO: FIX THIS, to do... what?
+use lib '/usr/local/lib/swish-e/perl';  # for source installs, so we can find SWISH::DefaultHighlight.pm
+use lib '/usr/libexec/swish-e/perl/';   # for rpm installs, so we can find SWISH::DefaultHighlight.pm
+use lib '/sw/lib/swish-e/perl';         # for fink-installed SWISH::DefaultHightlight. TODO: cleanup.
 
 # this checks if the SWISH::API is recent enough to have 
 # the features we use. returns 1 if yes, 0 otherwise
@@ -23,13 +30,31 @@ sub CheckSwisheVersion {
 	#	}
 	#};
 	my $class = "SWISH::API";
-	eval "require $class"; 
-
-	return 0 if $@;	
+	eval "require $class"; 	# if the class exists, this should load it
+    
+    if ($@) {
+        warn "$0: Can't load $class\n";
+        return 0;
+    }
 
 	no strict 'vars';
 	use vars qw( $SWISH::API::VERSION );
 	unless ($SWISH::API::VERSION && $SWISH::API::VERSION >= 0.03) {
+		# PAUSE namespace indexer complains about the line above:
+			# " The PAUSE indexer was not able to parse the following line
+			# in that file: C< unless ($SWISH::API::VERSION &&
+			# $SWISH::API::VERSION >= 0.03) { > Note: the indexer is
+			# running in a Safe compartement and cannot provide the full
+			# functionality of perl in the VERSION line. It is trying
+			# hard, but sometime it fails. As a workaround, please
+			# consider writing a proper META.yml that contains a
+			# 'provides' attribute (currently only supported by
+			# Module::Build) or contact the CPAN admins to investigate
+			# (yet another) workaround against "Safe" limitations.) "
+
+		# I don't understand why the namespace indexer needs to parse (run) this function
+
+        warn "$0: Can't run: need SWISH::API >= 0.03\n";
 		$@ = "Can't run: need SWISH::API >= 0.03\n"; 	# SET $@ for caller, if they check
 		return 0;
 	}
@@ -75,16 +100,16 @@ sub WriteFile {
 	# given a command and optional tmpdir, returns (stdout, stderr, $?) 
 	# uses the shell underneath
 	sub RunCommand {
-		my ($cmd, $tmpdir) = @_;
+		my ($cmd, $tmpdir, $should_be_undef) = @_;
+        die "$0: Internal Error: Sman::Util::RunCommand called with three arguments\n" 
+            if $should_be_undef;
 		$tmpdir = "/tmp" unless defined $tmpdir;
 		my ($out, $err) = ("", "");
 		my $r = sprintf("%04d", rand(9999));
 		my ($ofh, $outfile) = File::Temp::tempfile( "cmd-out.XXXXX", DIR => $tmpdir);
 		my ($efh, $errfile) = File::Temp::tempfile( "cmd-err.XXXXX", DIR => $tmpdir);
-		#my ($outfile, $errfile) = 
-		#	("$tmpdir/cmd" . $$ . "_$r.out", "$tmpdir/cmd" . $$ . "_$r.err");
 		# use two temporary filenames 
-		my $torun = "$cmd 1> $outfile 2>$errfile";
+		my $torun = "$cmd 1>$outfile 2>$errfile";
 		push(@tmpfiles, $outfile, $errfile);	# in case of SIG
 		#print "RUNNING $torun\n";
 		system($torun);
@@ -121,7 +146,7 @@ sub WriteFile {
 
 sub GetIndexDescriptionString {
 	my ($index) = @_;
-	my $indexmodtime = (stat($index))[9];
+	my $indexmodtime = (stat( "$index.prop" ))[9];
 	return sprintf("Using index %s, %s\n", 
 		$index, $indexmodtime ? "updated " . scalar(localtime( $indexmodtime ) ) : "(index not found)" );
 }
@@ -130,7 +155,7 @@ sub GetVersionString {
 	my ($prog, $swishecmd) = @_;
 	require SWISH::API;	# for $VERSION
 	require Sman;		# for $VERSION
-	my $str = "$prog $Sman::VERSION, using SWISH::API $SWISH::API::VERSION";
+	my $str = "$prog $Sman::Util::VERSION, using SWISH::API $SWISH::API::VERSION";
 	if ($swishecmd) {
 		my $cmd = $swishecmd . " -V";
 		my @lines = `$cmd`;
